@@ -106,7 +106,7 @@ the execution.
 This is probably best explained with the simple example file below.  You can
 copy this into a file named ex_demo.py, and try running it via::
 
-    from IPython.lib.demo import Demo
+    from IPython.demo import Demo
     d = Demo('ex_demo.py')
     d()
 
@@ -470,7 +470,7 @@ class Demo(object):
         if self.block_index == self.nblocks:
             mq1 = self.marquee('END OF DEMO')
             if mq1:
-                # avoid spurious print if empty marquees are used
+                # avoid spurious print >>io.stdout,s if empty marquees are used
                 print()
                 print(mq1)
                 print(self.marquee('Use <demo_name>.reset() if you want to rerun it.'))
