@@ -1,12 +1,12 @@
 import signal
 import sys
 
-from prompt_toolkit1.enums import DEFAULT_BUFFER, SEARCH_BUFFER
-from prompt_toolkit1.filters import (HasFocus, HasSelection, Condition,
+from prompt_toolkit.enums import DEFAULT_BUFFER, SEARCH_BUFFER
+from prompt_toolkit.filters import (HasFocus, HasSelection, Condition,
     ViInsertMode, EmacsInsertMode, HasCompletions)
-from prompt_toolkit1.filters.cli import ViMode
-from prompt_toolkit1.keys import Keys
-from prompt_toolkit1.key_binding.bindings.completion import display_completions_like_readline
+from prompt_toolkit.filters.cli import ViMode
+from prompt_toolkit.keys import Keys
+from prompt_toolkit.key_binding.bindings.completion import display_completions_like_readline
 
 from IPython.utils.decorators import undoc
 
@@ -16,7 +16,7 @@ def cursor_in_leading_ws(cli):
     return (not before) or before.isspace()
 
 def register_ipython_shortcuts(registry, shell):
-    """Set up the prompt_toolkit1 keyboard shortcuts for IPython"""
+    """Set up the prompt_toolkit keyboard shortcuts for IPython"""
     insert_mode = ViInsertMode() | EmacsInsertMode()
 
     # Ctrl+J == Enter, seemingly
@@ -26,8 +26,6 @@ def register_ipython_shortcuts(registry, shell):
                                  & insert_mode
                         ))(newline_or_execute_outer(shell))
 
-    registry.add_binding(Keys.ControlBackslash)(force_exit)
-
     registry.add_binding(Keys.ControlP,
                          filter=(ViInsertMode() & HasFocus(DEFAULT_BUFFER)
                         ))(previous_history_or_previous_completion)
@@ -58,14 +56,6 @@ def register_ipython_shortcuts(registry, shell):
                                  & cursor_in_leading_ws
                         ))(indent_buffer)
 
-    registry.add_binding(Keys.ControlO,
-                         filter=(HasFocus(DEFAULT_BUFFER)
-                                & EmacsInsertMode()))(newline_with_copy_margin)
-
-    registry.add_binding(Keys.F2,
-                         filter=HasFocus(DEFAULT_BUFFER)
-                        )(open_input_in_editor)
-
     if shell.display_completions == 'readlinelike':
         registry.add_binding(Keys.ControlI,
                              filter=(HasFocus(DEFAULT_BUFFER)
@@ -96,20 +86,13 @@ def newline_or_execute_outer(shell):
                 b.cancel_completion()
             return
 
-        # If there's only one line, treat it as if the cursor is at the end.
-        # See https://github.com/ipython/ipython/issues/10425
-        if d.line_count == 1:
-            check_text = d.text
-        else:
-            check_text = d.text[:d.cursor_position]
-        status, indent = shell.input_splitter.check_complete(check_text + '\n')
-
-        if not (d.on_last_line or
-                d.cursor_position_row >= d.line_count - d.empty_line_count_at_the_end()
-                ):
-            b.insert_text('\n' + (' ' * (indent or 0)))
+        if not (d.on_last_line or d.cursor_position_row >= d.line_count
+            - d.empty_line_count_at_the_end()):
+            b.newline()
             return
 
+        status, indent = shell.input_splitter.check_complete(d.text + '\n')
+
         if (status != 'incomplete') and b.accept_action.is_returnable:
             b.accept_action.validate_and_handle(event.cli, b)
         else:
@@ -158,32 +141,10 @@ def reset_search_buffer(event):
 def suspend_to_bg(event):
     event.cli.suspend_to_background()
 
-def force_exit(event):
-    """
-    Force exit (with a non-zero return value)
-    """
-    sys.exit("Quit")
-
 def indent_buffer(event):
     event.current_buffer.insert_text(' ' * 4)
 
-def newline_with_copy_margin(event):
-    """
-    Preserve margin and cursor position when using
-    Control-O to insert a newline in EMACS mode
-    """
-    b = event.current_buffer
-    cursor_start_pos = b.document.cursor_position_col
-    b.newline(copy_margin=True)
-    b.cursor_up(count=1)
-    cursor_end_pos = b.document.cursor_position_col
-    if cursor_start_pos != cursor_end_pos:
-        pos_diff = cursor_start_pos - cursor_end_pos
-        b.cursor_right(count=pos_diff)
 
-def open_input_in_editor(event):
-    event.cli.current_buffer.tempfile_suffix = ".py"
-    event.cli.current_buffer.open_in_editor(event.cli)
 
 
 if sys.platform == 'win32':
