@@ -14,7 +14,6 @@ import atexit
 import os
 import sys
 import tempfile
-import warnings
 from warnings import warn
 
 from IPython.utils.decorators import undoc
@@ -39,12 +38,7 @@ class IOStream:
         def clone(meth):
             return not hasattr(self, meth) and not meth.startswith('_')
         for meth in filter(clone, dir(stream)):
-            try:
-                val = getattr(stream, meth)
-            except AttributeError:
-                pass
-            else:
-                setattr(self, meth, val)
+            setattr(self, meth, getattr(stream, meth))
 
     def __repr__(self):
         cls = self.__class__
@@ -87,16 +81,11 @@ class IOStream:
         pass
 
 # setup stdin/stdout/stderr to sys.stdin/sys.stdout/sys.stderr
-devnull = open(os.devnull, 'w')
+devnull = open(os.devnull, 'w') 
 atexit.register(devnull.close)
-
-# io.std* are deprecated, but don't show our own deprecation warnings
-# during initialization of the deprecated API.
-with warnings.catch_warnings():
-    warnings.simplefilter('ignore', DeprecationWarning)
-    stdin = IOStream(sys.stdin, fallback=devnull)
-    stdout = IOStream(sys.stdout, fallback=devnull)
-    stderr = IOStream(sys.stderr, fallback=devnull)
+stdin = IOStream(sys.stdin, fallback=devnull)
+stdout = IOStream(sys.stdout, fallback=devnull)
+stderr = IOStream(sys.stderr, fallback=devnull)
 
 class Tee(object):
     """A class to duplicate an output stream to stdout/err.
