@@ -6,11 +6,11 @@
 
 from __future__ import print_function
 
-import logging
 from copy import deepcopy
+import warnings
 
-from .loader import Config, LazyConfigValue
-from traitlets.traitlets import HasTraits, Instance
+from .loader import Config, LazyConfigValue, _is_section_key
+from traitlets.traitlets import HasTraits, Instance, observe, observe_compat, default
 from ipython_genutils.text import indent, dedent, wrap_paragraphs
 from ipython_genutils.py3compat import iteritems
 
@@ -152,18 +152,25 @@ class Configurable(HasTraits):
                     # config object. If we don't, a mutable config_value will be
                     # shared by all instances, effectively making it a class attribute.
                     setattr(self, name, deepcopy(config_value))
-                elif isinstance(self, LoggingConfigurable):
+                elif not _is_section_key(name) and not isinstance(config_value, Config):
                     from difflib import get_close_matches
+                    if isinstance(self, LoggingConfigurable):
+                        warn = self.log.warning
+                    else:
+                        warn = lambda msg: warnings.warn(msg, stacklevel=9)
                     matches = get_close_matches(name, traits)
+                    msg = u"Config option `{option}` not recognized by `{klass}`.".format(
+                        option=name, klass=self.__class__.__name__)
+                    
                     if len(matches) == 1:
-                        self.log.warning(u"Config option `{option}` not recognized by `{klass}`, do you mean : `{matches}`"
-                                .format(option=name, klass=type(self).__name__, matches=matches[0]))
+                        msg += u"  Did you mean `{matches}`?".format(matches=matches[0])
                     elif len(matches) >= 1:
-                        self.log.warning(u"Config option `{option}` not recognized by `{klass}`, do you mean one of : `{matches}`"
-                                .format(option=name, klass=type(self).__name__, matches=' ,'.join(matches)))
+                        msg +="  Did you mean one of: `{matches}`?".format(matches=', '.join(sorted(matches)))
+                    warn(msg)
 
-
-    def _config_changed(self, name, old, new):
+    @observe('config')
+    @observe_compat
+    def _config_changed(self, change):
         """Update all the class traits having ``config=True`` in metadata.
 
         For any class trait with a ``config`` metadata attribute that is
@@ -177,27 +184,28 @@ class Configurable(HasTraits):
         # classes that are Configurable subclasses.  This starts with Configurable
         # and works down the mro loading the config for each section.
         section_names = self.section_names()
-        self._load_config(new, traits=traits, section_names=section_names)
+        self._load_config(change['new'], traits=traits, section_names=section_names)
 
     def update_config(self, config):
-        """Update config and trigger reload of config via trait events"""
-        # Save a copy of the old config
-        oldconfig = deepcopy(self.config)
-        # merge new config
+        """Update config and load the new values"""
+        # traitlets prior to 4.2 created a copy of self.config in order to trigger change events.
+        # Some projects (IPython < 5) relied upon one side effect of this,
+        # that self.config prior to update_config was not modified in-place.
+        # For backward-compatibility, we must ensure that self.config
+        # is a new object and not modified in-place,
+        # but config consumers should not rely on this behavior.
+        self.config = deepcopy(self.config)
+        # load config
+        self._load_config(config)
+        # merge it into self.config
         self.config.merge(config)
-        # unconditionally notify trait change, which triggers load of new config
-        self._notify_change('config', 'trait_change', {
-            'name': 'config',
-            'old': oldconfig,
-            'new': self.config,
-            'owner': self,
-            'type': 'trait_change', 
-        })
+        # TODO: trigger change event if/when dict-update change events take place
+        # DO NOT trigger full trait-change
 
     @classmethod
     def class_get_help(cls, inst=None):
         """Get the help string for this class in ReST format.
-        
+
         If `inst` is given, it's current trait values will be used in place of
         class defaults.
         """
@@ -329,6 +337,7 @@ class LoggingConfigurable(Configurable):
     """
 
     log = Instance('logging.Logger')
+    @default('log')
     def _log_default(self):
         from traitlets import log
         return log.get_logger()
